##  Key Features
The following table lists features included in the Apptio integration.
Base Integration | Advanced Integration
---|---
  * Export information from SAP LeanIX to Apptio through the SAP LeanIX Integration API
  * Schedule periodic data pulls from SAP LeanIX to Apptio
  * Out-of-the-box export of the following Fact Sheet types with predefined fields and all relevant relations:
    * Organization
    * Business Capability
    * Application
    * IT Component
    * Provider
    * Projects
  * Apptio API user credentials
  * Configuration options to select which Fact Sheets, relations, and attributes are exported
  * Configurable extension of the fields that are exported
  * Access existing or build new Dashboards & Reports in Apptio

|  All features included in the Base integration, plus the following:
  * Import data from Apptio to SAP LeanIX
  * On demand data pulls from Apptio to SAP LeanIX
  * Link to Fact Sheet-specific detail page in Apptio
  * Synchronize Fact Sheets
  * Cost fields
  * Fact Sheet level cost view
  * Fact Sheet level cost over time (metric)
  * Search “Filtering by cost type”
  * Cost view for Reports and Diagrams
  * Manual or scheduled execution of data export




